==> cloudcomponents.cdk-blue-green-container-deployment-1.22.0.tar.gz: package/lib/lambdas/ecs-deployment-group/index.js <==
module.exports =
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 2);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports) {

module.exports = require("aws-sdk");

/***/ }),
/* 1 */,
/* 2 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";

Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const aws_sdk_1 = __webpack_require__(0);
var RollbackEvent;
(function (RollbackEvent) {
    RollbackEvent["DEPLOYMENT_FAILURE"] = "DEPLOYMENT_FAILURE";
    RollbackEvent["DEPLOYMENT_STOP_ON_ALARM"] = "DEPLOYMENT_STOP_ON_ALARM";
    RollbackEvent["DEPLOYMENT_STOP_ON_REQUEST"] = "DEPLOYMENT_STOP_ON_REQUEST";
})(RollbackEvent || (RollbackEvent = {}));
const codeDeploy = new aws_sdk_1.CodeDeploy();
const getProperties = (props) => ({
    applicationName: props.ApplicationName,
    deploymentGroupName: props.DeploymentGroupName,
    serviceRoleArn: props.ServiceRoleArn,
    ecsServices: props.EcsServices.map(({ ClusterName, ServiceName }) => ({
        clusterName: ClusterName,
        serviceName: ServiceName,
    })),
    targetGroupNames: props.TargetGroupNames,
    prodTrafficListenerArn: props.ProdTrafficListenerArn,
    testTrafficListenerArn: props.TestTrafficListenerArn,
    terminationWaitTimeInMinutes: props.TerminationWaitTimeInMinutes,
    autoRollbackOnEvents: props.AutoRollbackOnEvents,
});
const onCreate = async (event) => {
    const { applicationName, deploymentGroupName, serviceRoleArn, ecsServices, targetGroupNames, prodTrafficListenerArn, testTrafficListenerArn, terminationWaitTimeInMinutes, autoRollbackOnEvents, } = getProperties(event.ResourceProperties);
    await codeDeploy
        .createDeploymentGroup({
        applicationName,
        deploymentGroupName,
        serviceRoleArn,
        ecsServices,
        loadBalancerInfo: {
            targetGroupPairInfoList: [
                {
                    prodTrafficRoute: {
                        listenerArns: [prodTrafficListenerArn],
                    },
                    testTrafficRoute: {
                        listenerArns: [testTrafficListenerArn],
                    },
                    targetGroups: targetGroupNames.map((name) => ({
                        name,
                    })),
                },
            ],
        },
        autoRollbackConfiguration: {
            enabled: !!autoRollbackOnEvents,
            events: autoRollbackOnEvents,
        },
        blueGreenDeploymentConfiguration: {
            terminateBlueInstancesOnDeploymentSuccess: {
                action: 'TERMINATE',
                terminationWaitTimeInMinutes,
            },
            deploymentReadyOption: {
                actionOnTimeout: 'CONTINUE_DEPLOYMENT',
            },
        },
        deploymentStyle: {
            deploymentType: 'BLUE_GREEN',
            deploymentOption: 'WITH_TRAFFIC_CONTROL',
        },
    })
        .promise();
    return {
        PhysicalResourceId: deploymentGroupName,
    };
};
const onUpdate = async (event) => {
    const newProps = getProperties(event.ResourceProperties);
    const oldProps = getProperties(event.OldResourceProperties);
    await codeDeploy
        .updateDeploymentGroup({
        applicationName: oldProps.applicationName,
        currentDeploymentGroupName: oldProps.deploymentGroupName,
        newDeploymentGroupName: newProps.deploymentGroupName,
        ecsServices: newProps.ecsServices,
        loadBalancerInfo: {
            targetGroupPairInfoList: [
                {
                    prodTrafficRoute: {
                        listenerArns: [newProps.prodTrafficListenerArn],
                    },
                    testTrafficRoute: {
                        listenerArns: [newProps.testTrafficListenerArn],
                    },
                    targetGroups: newProps.targetGroupNames.map((name) => ({
                        name,
                    })),
                },
            ],
        },
        autoRollbackConfiguration: {
            enabled: !!newProps.autoRollbackOnEvents,
            events: newProps.autoRollbackOnEvents,
        },
        blueGreenDeploymentConfiguration: {
            terminateBlueInstancesOnDeploymentSuccess: {
                action: 'TERMINATE',
                terminationWaitTimeInMinutes: newProps.terminationWaitTimeInMinutes,
            },
            deploymentReadyOption: {
                actionOnTimeout: 'CONTINUE_DEPLOYMENT',
            },
        },
    })
        .promise();
    return {
        PhysicalResourceId: newProps.deploymentGroupName,
    };
};
const onDelete = async (event) => {
    const { applicationName, deploymentGroupName } = getProperties(event.ResourceProperties);
    await codeDeploy
        .deleteDeploymentGroup({
        applicationName,
        deploymentGroupName,
    })
        .promise();
};
const handler = async (event) => {
    const requestType = event.RequestType;
    switch (requestType) {
        case 'Create':
            return onCreate(event);
        case 'Update':
            return onUpdate(event);
        case 'Delete':
            return onDelete(event);
        default:
            throw new Error(`Invalid request type: ${requestType}`);
    }
};
exports.handler = handler;


/***/ })
/******/ ]);
//# sourceMappingURL=index.js.map

==> cloudcomponents.cdk-blue-green-container-deployment-1.40.0.tar.gz: package/lib/lambdas/ecs-deployment-group/index.js <==
module.exports =
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 2);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ (function(module, exports) {

module.exports = require("aws-sdk");

/***/ }),
/* 1 */,
/* 2 */
/***/ (function(module, exports, __webpack_require__) {

"use strict";

Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const aws_sdk_1 = __webpack_require__(0);
var RollbackEvent;
(function (RollbackEvent) {
    RollbackEvent["DEPLOYMENT_FAILURE"] = "DEPLOYMENT_FAILURE";
    RollbackEvent["DEPLOYMENT_STOP_ON_ALARM"] = "DEPLOYMENT_STOP_ON_ALARM";
    RollbackEvent["DEPLOYMENT_STOP_ON_REQUEST"] = "DEPLOYMENT_STOP_ON_REQUEST";
})(RollbackEvent || (RollbackEvent = {}));
const codeDeploy = new aws_sdk_1.CodeDeploy();
const getProperties = (props) => ({
    applicationName: props.ApplicationName,
    deploymentGroupName: props.DeploymentGroupName,
    serviceRoleArn: props.ServiceRoleArn,
    ecsServices: props.EcsServices.map(({ ClusterName, ServiceName }) => ({
        clusterName: ClusterName,
        serviceName: ServiceName,
    })),
    targetGroupNames: props.TargetGroupNames,
    prodTrafficListenerArn: props.ProdTrafficListenerArn,
    testTrafficListenerArn: props.TestTrafficListenerArn,
    terminationWaitTimeInMinutes: props.TerminationWaitTimeInMinutes,
    autoRollbackOnEvents: props.AutoRollbackOnEvents,
    deploymentConfigName: props.DeploymentConfigName,
});
const onCreate = async (event) => {
    const { applicationName, deploymentGroupName, serviceRoleArn, ecsServices, targetGroupNames, prodTrafficListenerArn, testTrafficListenerArn, terminationWaitTimeInMinutes, autoRollbackOnEvents, deploymentConfigName, } = getProperties(event.ResourceProperties);
    await codeDeploy
        .createDeploymentGroup({
        applicationName,
        deploymentGroupName,
        serviceRoleArn,
        ecsServices,
        loadBalancerInfo: {
            targetGroupPairInfoList: [
                {
                    prodTrafficRoute: {
                        listenerArns: [prodTrafficListenerArn],
                    },
                    testTrafficRoute: {
                        listenerArns: [testTrafficListenerArn],
                    },
                    targetGroups: targetGroupNames.map((name) => ({
                        name,
                    })),
                },
            ],
        },
        autoRollbackConfiguration: {
            enabled: !!autoRollbackOnEvents,
            events: autoRollbackOnEvents,
        },
        blueGreenDeploymentConfiguration: {
            terminateBlueInstancesOnDeploymentSuccess: {
                action: 'TERMINATE',
                terminationWaitTimeInMinutes,
            },
            deploymentReadyOption: {
                actionOnTimeout: 'CONTINUE_DEPLOYMENT',
            },
        },
        deploymentStyle: {
            deploymentType: 'BLUE_GREEN',
            deploymentOption: 'WITH_TRAFFIC_CONTROL',
        },
        deploymentConfigName: deploymentConfigName !== null && deploymentConfigName !== void 0 ? deploymentConfigName : 'CodeDeployDefault.ECSAllAtOnce',
    })
        .promise();
    return {
        PhysicalResourceId: deploymentGroupName,
    };
};
const onUpdate = async (event) => {
    const newProps = getProperties(event.ResourceProperties);
    const oldProps = getProperties(event.OldResourceProperties);
    await codeDeploy
        .updateDeploymentGroup({
        applicationName: oldProps.applicationName,
        currentDeploymentGroupName: oldProps.deploymentGroupName,
        newDeploymentGroupName: newProps.deploymentGroupName,
        ecsServices: newProps.ecsServices,
        loadBalancerInfo: {
            targetGroupPairInfoList: [
                {
                    prodTrafficRoute: {
                        listenerArns: [newProps.prodTrafficListenerArn],
                    },
                    testTrafficRoute: {
                        listenerArns: [newProps.testTrafficListenerArn],
                    },
                    targetGroups: newProps.targetGroupNames.map((name) => ({
                        name,
                    })),
                },
            ],
        },
        autoRollbackConfiguration: {
            enabled: !!newProps.autoRollbackOnEvents,
            events: newProps.autoRollbackOnEvents,
        },
        blueGreenDeploymentConfiguration: {
            terminateBlueInstancesOnDeploymentSuccess: {
                action: 'TERMINATE',
                terminationWaitTimeInMinutes: newProps.terminationWaitTimeInMinutes,
            },
            deploymentReadyOption: {
                actionOnTimeout: 'CONTINUE_DEPLOYMENT',
            },
        },
        deploymentConfigName: newProps.deploymentConfigName,
    })
        .promise();
    return {
        PhysicalResourceId: newProps.deploymentGroupName,
    };
};
const onDelete = async (event) => {
    const { applicationName, deploymentGroupName } = getProperties(event.ResourceProperties);
    await codeDeploy
        .deleteDeploymentGroup({
        applicationName,
        deploymentGroupName,
    })
        .promise();
};
const handler = async (event) => {
    const requestType = event.RequestType;
    switch (requestType) {
        case 'Create':
            return onCreate(event);
        case 'Update':
            return onUpdate(event);
        case 'Delete':
            return onDelete(event);
        default:
            throw new Error(`Invalid request type: ${requestType}`);
    }
};
exports.handler = handler;


/***/ })
/******/ ]);
//# sourceMappingURL=index.js.map
